@@ -2,8 +2,7 @@ from .requestor import APIRequestor
 
 
 def api_test(error: str = None, **kwargs):
-    """Tests the ability to connect to the API
-    """
+    """Tests the ability to connect to the API"""
     params = {}
     if error:
         params["error"] = error
