@@ -2,8 +2,7 @@ from .requestor import APIRequestor
 
 
 def auth_test(error: str = None, **kwargs):
-    """Tests validity of your credentials
-    """
+    """Tests validity of your credentials"""
     params = {}
     if error:
         params["error"] = error
