@@ -28,8 +28,7 @@ class HTTPClient(object):
         self._thread_local = threading.local()
 
     def request_with_polling(self, method, url, headers, post_data=None):
-        """Handles retrying requests that are known to require polling
-        """
+        """Handles retrying requests that are known to require polling"""
         num_polls = 0
 
         while True:
@@ -60,7 +59,7 @@ class HTTPClient(object):
 
     def request_with_retries(self, method, url, headers, post_data=None):
         """
-            Handles network retries.
+        Handles network retries.
         """
         self._add_telemetry_header(headers)
 
