@@ -8,17 +8,24 @@ from mondobrain.api.util import encode_multipart, get_token
 
 
 class APIRequestor(object):
-    def __init__(self, token=None, client=None, api_base=None):
+    def __init__(self, token=None, client=None, api_base=None, auth_enabled=None):
         self.api_base = api_base or mondobrain.api_base
         self.api_token = token or mondobrain.api_token
+        self.auth_enabled = mondobrain.auth_enabled
 
-        if token:
-            self.api_token = token
-        elif mondobrain.api_token:
-            self.api_token = mondobrain.api_token
-        else:
-            mondobrain.api_token = get_token(mondobrain.api_key, mondobrain.api_secret)
-            self.api_token = mondobrain.api_token
+        if auth_enabled is not None:
+            self.auth_enabled = auth_enabled
+
+        if self.auth_enabled:
+            if token:
+                self.api_token = token
+            elif mondobrain.api_token:
+                self.api_token = mondobrain.api_token
+            else:
+                mondobrain.api_token = get_token(
+                    mondobrain.api_key, mondobrain.api_secret
+                )
+                self.api_token = mondobrain.api_token
 
         from mondobrain import verify_ssl_certs as verify
 
@@ -86,10 +93,13 @@ class APIRequestor(object):
         headers = {
             "X-Mondobrain-Client-User-Agent": json.dumps(ua),
             "User-Agent": user_agent,
-            "Authorization": "Bearer %s" % (api_token,),
             "Content-Type": "application/json",
         }
 
+        # Only add authorization header if auth is enabled
+        if self.auth_enabled:
+            headers["Authorization"] = "Bearer %s" % (api_token,)
+
         return headers
 
     def request_raw(self, method, url, params=None, supplied_headers=None):
