@@ -14,17 +14,28 @@ def _condition_mask(s: pd.Series, cond: Union[dict, str]):
     return s == cond
 
 
-def conditions_mask(df: pd.DataFrame, rule: dict):
+def conditions_mask(df: Union[pd.Series, pd.DataFrame], rule: dict):
     """ Get a mask based on a dictionary of conditions
     """
     masks = []
     for key, cond in rule.items():
         masks.append(_condition_mask(df[key], cond))
 
-    return np.all(np.array(masks), axis=0)
+    if isinstance(df, pd.Series):
+        return (
+            np.ones(df.size, dtype=np.bool)
+            if np.all(masks)
+            else np.zeros(df.size, dtype=np.bool)
+        )
+    elif df.shape[0] == 1:
+        return np.array([np.all([mask.values for mask in masks])])
+    else:
+        return np.all(np.array(masks), axis=0)
 
 
-def apply_rule(df: pd.DataFrame, rule: dict, inverse: bool = False) -> pd.DataFrame:
+def apply_rule(
+    df: Union[pd.Series, pd.DataFrame], rule: dict, inverse: bool = False
+) -> pd.DataFrame:
     """ Applies the rule to the population df to obtain a sample
 
     Parameters
