@@ -1,3 +1,4 @@
+from ._bias import bias
 from ._correlation import correlation_groups, correlation_matrix
 from ._encoded import encoded_mean
 from ._score import feature_signals, partial_scores, score
@@ -11,4 +12,5 @@ __all__ = [
     "correlation_matrix",
     "correlation_groups",
     "feature_signals",
+    "bias",
 ]
