@@ -3,7 +3,7 @@ import pandas as pd
 
 
 def target_metrics(s: pd.Series, target: str = None) -> dict:
-    """ Get metrics for a target within a column
+    """Get metrics for a target within a column
 
     Parameters
     ----------
@@ -13,6 +13,21 @@ def target_metrics(s: pd.Series, target: str = None) -> dict:
     target: str, default=None
         The class in s to calculate metrics for. For a continuous outcome this should
         either be `min` or `max`. If None, then the first class or `max` is selected.
+
+    Examples
+    --------
+    >>> from mondobrain.datasets import load_titanic
+    >>> from mondobrain import metrics
+    >>> df = load_titanic()
+    >>> series = df['survived']
+    >>> target = "Died"
+    >>> metrics.target_metrics(series, target)
+    {
+        'mean': 0.617737003058104,
+        'std': 0.48594032361072487,
+        'size': 1308,
+        'size_above_mean': 808
+    }
     """
     if target is None:
         target = s[0] if s.dtype == np.object else "max"
