@@ -225,35 +225,32 @@ class Solver:
         explorable_vars = [col for col in m_X.columns if col != m_y.name]
         m_X = m_X[explorable_vars].copy()
 
-        if isinstance(cv, int) or isinstance(cv, float):
-            cv = KFold(n_splits=cv, shuffle=True)
+        mdf = MondoDataFrame(pd.concat((MondoDataFrame(m_y), m_X), axis=1))
 
-        if cv is None:
-            X_train, X_test, y_train, y_test = m_X, None, m_y, None
-        else:
-            X_train, X_test, y_train, y_test = train_test_split(
-                m_X, m_y, test_size=0.33, random_state=1337
-            )
-            y_train.target_class = y_test.target_class = m_y.target_class
-
-        mdf = MondoDataFrame(pd.concat((MondoDataFrame(y_train), X_train), axis=1))
-
-        outcome = m_y.name
-        target = m_y.target_class
+        self.outcome = m_y.name
+        self.target = m_y.target_class
 
         self.rule, sample_stats, self.score, self.discarded_rules = self._run_solve(
-            mdf, outcome, target
+            mdf, self.outcome, self.target
         )
 
         self.size = sample_stats["size"]
         self.mean = sample_stats["mean"]
         self.rule_data = self.get_rule_data(mdf)
 
+        # adding this to store the mdf specific to this solve
+        self.df = mdf
+
         if cv is not None:
             self.validation = utilities.cross_validate_rule(
-                self.rule, X_test, y_test, cv=cv, score=self.score
+                self.rule, m_X, m_y, cv=cv, score=self.score
             )
 
+    def readable_rule(self):
+        utilities.get_readable_rule(
+            self.rule, self.score, self.size, self.outcome, self.target
+        )
+
     def fit_predicted(
         self,
         m_X,
@@ -333,8 +330,8 @@ class Solver:
 
         mdf = MondoDataFrame(pd.concat((MondoDataFrame(y_error), m_X), axis=1))
 
-        outcome = y_error.name
-        target = y_error.target_class
+        self.outcome = outcome = y_error.name
+        self.target = target = y_error.target_class
 
         min_size_frac_orig = self.min_size_frac
 
@@ -502,79 +499,96 @@ class Solver:
 
         scores: dict of float arrays of shape (n_splits,).  The possible keys for
             this dictionary are as follows:
-            - train_scores: an array of scores when finding rules on validation sets
-            - train_sizes: an array of sizes of rules on the training sets
-            - test_scores: an array of scores when applying the rule on the test set
-            - test_sizes: an array of sizes of rules on the test sets
+            - train_scores: an array of rule scores that were learned on training sets
+            - train_sizes: an array of rule sizes that were learned on training sets
+            - test_scores: an array of rule scores when applied to the test set
+            - test_sizes: an array of rule sizes when applied to the test set
+            - validation_scores: an array of rule scores when applied to validation sets
+            - validation_sizes: an array of rule sizes when applied to validation sets
             - rules: an array of rules (see solver.rule for object definition)
             - avg_loss: the mean squared error between train and test scores
 
         """
 
+        def get_stats(df, rule, outcome, target):
+            df_applied = utilities.apply_rule_to_df(df, rule)
+
+            sample_stats = utilities.get_stats(df_applied, outcome, target)
+            score = utilities.score_rule(df, rule, outcome, target)
+            size = sample_stats["size"]
+
+            return score, size
+
         if isinstance(cv, int) or isinstance(cv, float):
             cv = KFold(n_splits=cv, shuffle=True)
 
+        explorable_vars = [col for col in m_X.columns if col != m_y.name]
+        m_X = m_X[explorable_vars].copy()
+
         X_train, X_test, y_train, y_test = train_test_split(
             m_X, m_y, test_size=0.33, random_state=1337
         )
         y_train.target_class = y_test.target_class = m_y.target_class
 
-        full_mdf = MondoDataFrame(pd.concat((MondoDataFrame(m_y), m_X), axis=1))
-        mdf = MondoDataFrame(pd.concat((MondoDataFrame(y_test), X_test), axis=1))
+        mdf = MondoDataFrame(pd.concat((MondoDataFrame(m_y), m_X), axis=1))
+        mdf_test = MondoDataFrame(pd.concat((MondoDataFrame(y_test), X_test), axis=1))
+        outcome = m_y.name
+        target = m_y.target_class
 
         # For use in scoring later (_run_solve handles in-flight encoding)
-        encoder = DDTransformer(full_mdf)
-        edf = utilities.encode_dataframe(mdf, encoder)
+        encoder = DDTransformer(mdf)
+        edf_test = utilities.encode_dataframe(mdf_test, encoder)
+        outcome_encoded = encoder.original_to_encoded_column(outcome)
+        target_encoded = utilities.encode_value(mdf, outcome, target, encoder)
 
         train_scores, train_sizes = [], []
         test_scores, test_sizes = [], []
+        val_scores, val_sizes = [], []
         rules = []
 
-        for train_index, test_index in cv.split(X_train, y_train):
+        for train_index, val_index in cv.split(X_train, y_train):
             X_train_curr = X_train.iloc[train_index]
             y_train_curr = y_train.iloc[train_index]
 
-            mdf_curr = MondoDataFrame(
+            mdf_train = MondoDataFrame(
                 pd.concat((MondoDataFrame(y_train_curr), X_train_curr), axis=1)
             )
 
-            outcome = m_y.name
-            target = m_y.target_class
+            X_val = X_train.iloc[val_index]
+            y_val = y_train.iloc[val_index]
+
+            mdf_val = MondoDataFrame(pd.concat((MondoDataFrame(y_val), X_val), axis=1))
 
             (
                 train_rule,
                 train_sample_stats,
                 train_score,
                 discarded_rules,
-            ) = self._run_solve(mdf_curr, outcome, target)
+            ) = self._run_solve(mdf_train, outcome, target)
             train_size = train_sample_stats["size"]
 
             if m_y.var_type == "discrete":
                 # Discrete Stats - operate in original space
-                mdf_applied = utilities.apply_rule_to_df(mdf, train_rule)
-
-                test_sample_stats = utilities.get_stats(mdf_applied, outcome, target)
-                test_score = utilities.score_rule(mdf, train_rule, outcome, target)
-                test_size = test_sample_stats["size"]
+                test_score, test_size = get_stats(mdf_test, train_rule, outcome, target)
+                val_score, val_size = get_stats(mdf_val, train_rule, outcome, target)
             else:
                 # Continous Stats - operate in encoded space
-                rule_encoded = utilities.encode_rule(train_rule, encoder)
-                outcome_encoded = encoder._column_encoder[outcome]
+                train_rule_encoded = utilities.encode_rule(train_rule, encoder)
+                edf_val = utilities.encode_dataframe(mdf_val, encoder)
 
-                edf_applied = utilities.apply_rule_to_df(edf, rule_encoded)
-
-                test_sample_stats = utilities.get_stats(
-                    edf_applied, outcome_encoded, target
+                test_score, test_size = get_stats(
+                    edf_test, train_rule_encoded, outcome_encoded, target_encoded
                 )
-                test_score = utilities.score_rule(
-                    edf, rule_encoded, outcome_encoded, target
+                val_score, val_size = get_stats(
+                    edf_val, train_rule_encoded, outcome_encoded, target_encoded
                 )
-                test_size = test_sample_stats["size"]
 
             train_scores.append(train_score)
             train_sizes.append(train_size)
             test_scores.append(test_score)
             test_sizes.append(test_size)
+            val_scores.append(val_score)
+            val_sizes.append(val_size)
             rules.append(train_rule)
 
         mse = np.mean((np.array(train_scores) - np.array(test_scores)) ** 2)
@@ -584,8 +598,28 @@ class Solver:
             "train_sizes": train_sizes,
             "test_scores": test_scores,
             "test_sizes": test_sizes,
+            "validation_scores": val_scores,
+            "validation_sizes": val_sizes,
             "rules": rules,
             "avg_loss": mse,
         }
 
         return result
+
+    def bias(self, vars, rule=None):
+        """
+        Evaluate bias along selected variables within the segment
+
+        Calls function at mondobrain.metrics._bias.bias_test with
+        dataframe that was used to fit a rule
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        """
+        if not rule:
+            rule = self.rule
+
+        return mb.metrics.bias(self.df, vars, rule=rule)
